@@ -1,28 +1,26 @@
-# Copyright 2021 - 2025, nymea GmbH
-# Contact: contact@nymea.io
+# SPDX-License-Identifier: GPL-3.0-or-later
+
+# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# This file is part of nymea.
-# This project including source code and documentation is protected by
-# copyright law, and remains the property of nymea GmbH. All rights, including
-# reproduction, publication, editing and translation, are reserved. The use of
-# this project is subject to the terms of a license agreement to be concluded
-# with nymea GmbH in accordance with the terms of use of nymea GmbH, available
-# under https://nymea.io/license
+# Copyright (C) 2013 - 2024, nymea GmbH
+# Copyright (C) 2024 - 2025, chargebyte austria GmbH
 #
-# GNU General Public License Usage
-# Alternatively, this project may be redistributed and/or modified under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, GNU version 3. This project is distributed in the hope that it
-# will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
-# Public License for more details.
+# This file is part of nymea-plugins-modbus.
 #
-# You should have received a copy of the GNU General Public License along with
-# this project. If not, see <https://www.gnu.org/licenses/>.
+# nymea-plugins-modbus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-# For any further details and any questions please contact us under
-# contact@nymea.io or see our FAQ/Licensing Information on
-# https://nymea.io/license/faq
+# nymea-plugins-modbus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with nymea-plugins-modbus. If not, see <https://www.gnu.org/licenses/>.
+#
+# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
 import re
 import json
@@ -84,35 +82,27 @@ def writeLine(fileDescriptor, line = ''):
 
 
 def writeLicenseHeader(fileDescriptor):
-    writeLine(fileDescriptor, '/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *')
+    writeLine(fileDescriptor, '// SPDX-License-Identifier: GPL-3.0-or-later')
+    writeLine(fileDescriptor)
+    writeLine(fileDescriptor, '/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *')
     writeLine(fileDescriptor, '*')
-    writeLine(fileDescriptor, '* Copyright 2013 - %s, nymea GmbH' % datetime.datetime.now().year)
-    writeLine(fileDescriptor, '* Contact: contact@nymea.io')
+    writeLine(fileDescriptor, '* Copyright (C) 2013 - 2024, nymea GmbH')
+    writeLine(fileDescriptor, '* Copyright (C) 2013 - %s, chargebyte austria GmbH' % datetime.datetime.now().year)
     writeLine(fileDescriptor, '*')
-    writeLine(fileDescriptor, '* This fileDescriptor is part of nymea.')
-    writeLine(fileDescriptor, '* This project including source code and documentation is protected by')
-    writeLine(fileDescriptor, '* copyright law, and remains the property of nymea GmbH. All rights, including')
-    writeLine(fileDescriptor, '* reproduction, publication, editing and translation, are reserved. The use of')
-    writeLine(fileDescriptor, '* this project is subject to the terms of a license agreement to be concluded')
-    writeLine(fileDescriptor, '* with nymea GmbH in accordance with the terms of use of nymea GmbH, available')
-    writeLine(fileDescriptor, '* under https://nymea.io/license')
+    writeLine(fileDescriptor, '* nymea-plugins-modbus is free software: you can redistribute it and/or modify')
+    writeLine(fileDescriptor, '* it under the terms of the GNU General Public License as published by')
+    writeLine(fileDescriptor, '* the Free Software Foundation, either version 3 of the License, or')
+    writeLine(fileDescriptor, '* (at your option) any later version.')
     writeLine(fileDescriptor, '*')
-    writeLine(fileDescriptor, '* GNU Lesser General Public License Usage')
-    writeLine(fileDescriptor, '* Alternatively, this project may be redistributed and/or modified under the')
-    writeLine(fileDescriptor, '* terms of the GNU Lesser General Public License as published by the Free')
-    writeLine(fileDescriptor, '* Software Foundation; version 3. This project is distributed in the hope that')
-    writeLine(fileDescriptor, '* it will be useful, but WITHOUT ANY WARRANTY; without even the implied')
-    writeLine(fileDescriptor, '* warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU')
-    writeLine(fileDescriptor, '* Lesser General Public License for more details.')
+    writeLine(fileDescriptor, '* nymea-plugins-modbus is distributed in the hope that it will be useful,')
+    writeLine(fileDescriptor, '* but WITHOUT ANY WARRANTY; without even the implied warranty of')
+    writeLine(fileDescriptor, '* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the')
+    writeLine(fileDescriptor, '* GNU General Public License for more details.')
     writeLine(fileDescriptor, '*')
-    writeLine(fileDescriptor, '* You should have received a copy of the GNU Lesser General Public License')
-    writeLine(fileDescriptor, '* along with this project. If not, see <https://www.gnu.org/licenses/>.')
+    writeLine(fileDescriptor, '* You should have received a copy of the GNU General Public License')
+    writeLine(fileDescriptor, '* along with nymea-plugins-modbus. If not, see <https://www.gnu.org/licenses/>.')
     writeLine(fileDescriptor, '*')
-    writeLine(fileDescriptor, '* For any further details and any questions please contact us under')
-    writeLine(fileDescriptor, '* contact@nymea.io or see our FAQ/Licensing Information on')
-    writeLine(fileDescriptor, '* https://nymea.io/license/faq')
-    writeLine(fileDescriptor, '*')
-    writeLine(fileDescriptor, '* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */')
+    writeLine(fileDescriptor, '* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */')
     writeLine(fileDescriptor)
     writeLine(fileDescriptor, '/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *')
     writeLine(fileDescriptor, '*')
